==> libreoffice_7.0.4.orig.tar.xz: libreoffice-7.0.4.2/sc/qa/uitest/search_replace/tdf132783.py <==
# -*- tab-width: 4; indent-tabs-mode: nil; py-indent-offset: 4 -*-
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
from uitest.framework import UITestCase
from uitest.uihelper.common import get_state_as_dict
from libreoffice.uno.propertyvalue import mkPropertyValues
from uitest.path import get_srcdir_url

def get_url_for_data_file(file_name):
    return get_srcdir_url() + "/sc/qa/uitest/calc_tests/data/" + file_name

class tdf132783(UITestCase):

   def test_tdf132783(self):
        calc_doc = self.ui_test.load_file(get_url_for_data_file("tdf132783.ods"))

        for i in range(5):
            self.ui_test.execute_modeless_dialog_through_command(".uno:SearchDialog")
            xDialog = self.xUITest.getTopFocusWindow()
            xSearchTerm = xDialog.getChild("searchterm")

            xSearchTerm.executeAction("TYPE", mkPropertyValues({"TEXT":"1"}))

            xSearch = xDialog.getChild("search")
            xSearch.executeAction("CLICK", tuple())

            xcloseBtn = xDialog.getChild("close")
            self.ui_test.close_dialog_through_button(xcloseBtn)

            xGridWin = self.xUITest.getTopFocusWindow().getChild("grid_window")
            self.assertEqual(get_state_as_dict(xGridWin)["CurrentRow"], "1")
            self.assertEqual(get_state_as_dict(xGridWin)["CurrentColumn"], str( 96 + i))

        self.ui_test.close_doc()

# vim: set shiftwidth=4 softtabstop=4 expandtab:

==> libreoffice-7.1.3.2.tar.xz: libreoffice-7.1.3.2/sc/qa/uitest/search_replace/tdf132783.py <==
# -*- tab-width: 4; indent-tabs-mode: nil; py-indent-offset: 4 -*-
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
from uitest.framework import UITestCase
from uitest.uihelper.common import get_state_as_dict
from libreoffice.uno.propertyvalue import mkPropertyValues
import org.libreoffice.unotest
import pathlib

def get_url_for_data_file(file_name):
    return pathlib.Path(org.libreoffice.unotest.makeCopyFromTDOC(file_name)).as_uri()

class tdf132783(UITestCase):

   def test_tdf132783(self):
        calc_doc = self.ui_test.load_file(get_url_for_data_file("tdf132783.ods"))

        for i in range(5):
            self.ui_test.execute_modeless_dialog_through_command(".uno:SearchDialog")
            xDialog = self.xUITest.getTopFocusWindow()
            xSearchTerm = xDialog.getChild("searchterm")

            xSearchTerm.executeAction("TYPE", mkPropertyValues({"TEXT":"1"}))

            xSearch = xDialog.getChild("search")
            xSearch.executeAction("CLICK", tuple())

            xcloseBtn = xDialog.getChild("close")
            self.ui_test.close_dialog_through_button(xcloseBtn)

            xGridWin = self.xUITest.getTopFocusWindow().getChild("grid_window")
            self.assertEqual(get_state_as_dict(xGridWin)["CurrentRow"], "1")
            self.assertEqual(get_state_as_dict(xGridWin)["CurrentColumn"], str( 96 + i))

        self.ui_test.close_doc()

# vim: set shiftwidth=4 softtabstop=4 expandtab:
